@@ -12,26 +12,27 @@ from pathlib import Path
 
 # TODO improve consistency of variable names; think about variables to move in/out
 
-VersionTargetVar  = "PDFIUM_VERSION"
-BinaryTargetVar   = "PDFIUM_PLATFORM"
-BinaryTarget_None = "none"
-BinaryTarget_Auto = "auto"
-BindingsFileName  = "raw.py"
-VerStatusFileName = ".pdfium_version.txt"
-V8StatusFileName  = ".pdfium_is_v8.txt"
-HomeDir     = Path.home()
-SourceTree  = Path(__file__).parents[2]
-DataTree    = SourceTree / "data"
-SB_Dir      = SourceTree / "sourcebuild"
-ModuleDir   = SourceTree / "src" / "pypdfium2"
-VersionFile = ModuleDir / "version.py"
-Changelog   = SourceTree / "docs" / "devel" / "changelog.md"
-ChangelogStaging = SourceTree / "docs" / "devel" / "changelog_staging.md"
-RepositoryURL  = "https://github.com/pypdfium2-team/pypdfium2"
-PDFium_URL     = "https://pdfium.googlesource.com/pdfium"
-DepotTools_URL = "https://chromium.googlesource.com/chromium/tools/depot_tools.git"
-ReleaseRepo    = "https://github.com/bblanchon/pdfium-binaries"
-ReleaseURL     = ReleaseRepo + "/releases/download/chromium%2F"
+BinaryTargetVar      = "PDFIUM_PLATFORM"
+BinaryTarget_None    = "none"
+BinaryTarget_Auto    = "auto"
+VersionTargetVar     = "PDFIUM_VERSION"
+VersionTarget_Latest = "latest"
+BindingsFileName     = "raw.py"  # NOTE if you rename this, delete the file `bindings/$VALUE`
+VerStatusFileName    = ".pdfium_version.txt"
+V8StatusFileName     = ".pdfium_is_v8.txt"
+HomeDir              = Path.home()
+SourceTree           = Path(__file__).parents[2]
+DataTree             = SourceTree / "data"
+SB_Dir               = SourceTree / "sourcebuild"
+ModuleDir            = SourceTree / "src" / "pypdfium2"
+VersionFile          = ModuleDir / "version.py"
+Changelog            = SourceTree / "docs" / "devel" / "changelog.md"
+ChangelogStaging     = SourceTree / "docs" / "devel" / "changelog_staging.md"
+RepositoryURL        = "https://github.com/pypdfium2-team/pypdfium2"
+PDFium_URL           = "https://pdfium.googlesource.com/pdfium"
+DepotTools_URL       = "https://chromium.googlesource.com/chromium/tools/depot_tools.git"
+ReleaseRepo          = "https://github.com/bblanchon/pdfium-binaries"
+ReleaseURL           = ReleaseRepo + "/releases/download/chromium%2F"
 
 
 class SystemNames:
@@ -104,6 +105,7 @@ class _host_platform:
         # https://github.com/python/cpython/issues/87414
         # `libc_ver()` currently returns an empty string on libc implementations other than glibc - hence, we assume musl if it's not glibc
         # TODO find some function to actually detect musl
+        # See this for possible solutions: https://stackoverflow.com/questions/72272168/how-to-determine-which-libc-implementation-the-host-system-uses
         self._libc_info = None
         self._is_glibc = None
         if self._system_name == "linux":
