@@ -7,9 +7,8 @@ import sys
 import logging
 import argparse
 import importlib
-import pypdfium2._helpers as pdfium
-from pypdfium2._helpers._internal import bases
 from pypdfium2.version import *
+import pypdfium2._helpers as pdfium
 
 try:
     import argcomplete
@@ -18,16 +17,16 @@ except ImportError:
 
 
 SubCommands = {
-    "render":         "rasterize pages",
-    "toc":            "print table of contents",
     "arrange":        "rearrange/merge documents",
-    "tile":           "tile pages (N-up)",
-    "pdfinfo":        "print info on document and pages",
-    "pageobjects":    "print info on page objects",
-    "extract-text":   "extract text",
-    "extract-images": "extract images",
-    "imgtopdf":       "convert images to PDF",
     "attachments":    "list/extract/edit embedded files",
+    "extract-images": "extract images",
+    "extract-text":   "extract text",
+    "imgtopdf":       "convert images to PDF",
+    "pageobjects":    "print info on page objects",
+    "pdfinfo":        "print info on document and pages",
+    "render":         "rasterize pages",
+    "tile":           "tile pages (N-up)",
+    "toc":            "print table of contents",
 }
 
 CmdToModule = {n: importlib.import_module(f"pypdfium2._cli.{n.replace('-', '_')}") for n in SubCommands}
@@ -48,8 +47,7 @@ def get_parser():
     
     for name, help in SubCommands.items():
         subparser = subparsers.add_parser(name, description=help, help=help)
-        module = CmdToModule[name]
-        module.attach(subparser)
+        CmdToModule[name].attach(subparser)
     
     if argcomplete:
         argcomplete.autocomplete(main_parser)
@@ -59,8 +57,8 @@ def get_parser():
 
 def setup_logging():
     
-    # FIXME can we make some sort of public API to set this without a strange import?
-    bases.DEBUG_AUTOCLOSE = bool(int( os.environ.get("DEBUG_AUTOCLOSE", 0) ))
+    debug_autoclose = bool(int( os.environ.get("DEBUG_AUTOCLOSE", 0) ))
+    pdfium.internal.set_autoclose_debug(debug_autoclose)
     
     lib_logger = logging.getLogger("pypdfium2")
     lib_logger.addHandler(logging.StreamHandler())
@@ -73,12 +71,12 @@ def api_main(raw_args=sys.argv[1:]):
     
     parser = get_parser()
     args = parser.parse_args(raw_args)
+    
     if not args.subcommand:
         parser.print_help()
         return
     
-    module = CmdToModule[args.subcommand]
-    module.main(args)
+    CmdToModule[args.subcommand].main(args)
 
 
 def cli_main():
