@@ -33,10 +33,9 @@ def main(args):
     if pagemode != pdfium_c.PAGEMODE_USENONE:
         print(f"Page Mode: {consts.PageModeToStr.get(pagemode)}")
     
-    # FIXME use support model once implemented properly
-    formtype = pdfium_c.FPDF_GetFormType(pdf)
+    formtype = pdf.get_formtype()
     if formtype != pdfium_c.FORMTYPE_NONE:
-        print(f"Forms: {consts.FormTypeToStr.get(formtype)}")
+        print(f"Form Type: {consts.FormTypeToStr.get(formtype)}")
     
     metadata = pdf.get_metadata_dict(skip_empty=True)
     if len(metadata) > 0:
@@ -47,30 +46,13 @@ def main(args):
     for i in args.pages:
         
         print(f"\n# Page {i+1}")
+        
         page = pdf[i]
-        
-        size = round_list(page.get_size(), args.n_digits)
-        print(f"Size: {size}")
+        print(f"Size: {round_list(page.get_size(), args.n_digits)}")
         print(f"Rotation: {page.get_rotation()}")
+        print(f"Bounding Box: {round_list(page.get_bbox(), args.n_digits)}")
         
-        bbox = round_list(page.get_bbox(), args.n_digits)
-        print(f"Bounding Box: {bbox}")
-        
-        mediabox = round_list(page.get_mediabox(), args.n_digits)
-        print(f"MediaBox: {mediabox}")
-        
-        cropbox = round_list(page.get_cropbox(), args.n_digits)
-        if cropbox != mediabox:
-            print(f"CropBox: {cropbox}")
-        
-        bleedbox = round_list(page.get_bleedbox(), args.n_digits)
-        if bleedbox != cropbox:
-            print(f"BleedBox: {bleedbox}")
-        
-        trimbox = round_list(page.get_trimbox(), args.n_digits)
-        if trimbox != cropbox:
-            print(f"TrimBox: {trimbox}")
-        
-        artbox = round_list(page.get_artbox(), args.n_digits)
-        if artbox != cropbox:
-            print(f"ArtBox: {artbox}")
+        for box_name in ("media", "crop", "bleed", "trim", "art"):
+            box = getattr(page, f"get_{box_name.lower()}box")(fallback_ok=False)
+            if box:
+                print(f"{box_name.capitalize()}Box: {round_list(box, args.n_digits)}")
