@@ -36,8 +36,6 @@ class PdfDocument (AutoCloseable):
             If a password is given but the PDF is not encrypted, it will be ignored (as of PDFium 5418).
         autoclose (bool):
             Whether byte buffer input should be automatically closed on finalization.
-        may_init_forms (bool):
-            Whether a form env may be initialized, if the document has forms.
     
     Raises:
         PdfiumError: Raised if the document failed to load. The exception message is annotated with the reason reported by PDFium.
@@ -53,10 +51,7 @@ class PdfDocument (AutoCloseable):
         raw (FPDF_DOCUMENT):
             The underlying PDFium document handle.
         formenv (PdfFormEnv | None):
-            Form env, if the document has forms and ``may_init_forms=True``.
-        formtype (int):
-            PDFium form type that applies to the document (:attr:`FORMTYPE_*`).
-            :attr:`FORMTYPE_NONE` if the document has no forms or ``may_init_forms=False``.
+            Form env, if the document has forms and :meth:`.init_forms` was called.
     """
     
     def __init__(
@@ -64,7 +59,6 @@ class PdfDocument (AutoCloseable):
             input,
             password = None,
             autoclose = False,
-            may_init_forms = False,
         ):
         
         if isinstance(input, str):
@@ -80,6 +74,7 @@ class PdfDocument (AutoCloseable):
         
         self._data_holder = []
         self._data_closer = []
+        self.formenv = None
         
         if isinstance(self._input, pdfium_c.FPDF_DOCUMENT):
             self.raw = self._input
@@ -89,13 +84,6 @@ class PdfDocument (AutoCloseable):
             self._data_closer += to_close
         
         AutoCloseable.__init__(self, self._close_impl, self._data_holder, self._data_closer)
-        
-        # TODO make formtype a lazy property (it doesn't actually need a form env to retrieve)
-        self.formenv = None
-        self.formtype = pdfium_c.FORMTYPE_NONE
-        self._has_forms = False
-        if may_init_forms:
-            self._init_forms()
     
     
     @property
@@ -135,18 +123,6 @@ class PdfDocument (AutoCloseable):
         self.del_page(i)
     
     
-    def _init_forms(self):
-        self.formtype = pdfium_c.FPDF_GetFormType(self)
-        self._has_forms = self.formtype != pdfium_c.FORMTYPE_NONE  # TODO make public?
-        if self._has_forms:
-            if V_PDFIUM_IS_V8:
-                # BUG(182): would need a caller-provided form config ...
-                raise RuntimeError("pypdfium2's helpers do not support forms with V8 enabled binaries yet.")
-            formconfig = pdfium_c.FPDF_FORMFILLINFO(version=2)
-            raw = pdfium_c.FPDFDOC_InitFormFillEnvironment(self, formconfig)
-            self.formenv = PdfFormEnv(raw, formconfig, self)
-    
-    
     @classmethod
     def new(cls):
         """
@@ -157,6 +133,40 @@ class PdfDocument (AutoCloseable):
         return cls(new_pdf)
     
     
+    def init_forms(self, config=None):
+        """
+        Initialize a form env, if the document has forms. If already initialized, nothing will be done.
+        See the :attr:`formenv` attribute.
+    
+        Note:
+            If form rendering is desired, this method should be called directly after constructing the document,
+            before getting any page handles (due to PDFium's API).
+        
+        Parameters:
+            config (FPDF_FORMFILLINFO):
+                Caller-provided form config interface to use. Optional for default builds.
+                Must be given if using V8 enabled PDFium (:data:`.V_PDFIUM_IS_V8`), with all required fields implemented.
+        """
+        if (self.get_formtype() == pdfium_c.FORMTYPE_NONE) or self.formenv:
+            return
+        if not config:
+            if V_PDFIUM_IS_V8:
+                raise RuntimeError("A caller-provided form config is required with V8 enabled PDFium.")
+            else:
+                config = pdfium_c.FPDF_FORMFILLINFO(version=2)
+        raw = pdfium_c.FPDFDOC_InitFormFillEnvironment(self, config)
+        self.formenv = PdfFormEnv(raw, config, self)
+    
+    
+    def get_formtype(self):
+        """
+        Returns:
+            int: PDFium form type that applies to the document (:attr:`FORMTYPE_*`).
+            :attr:`FORMTYPE_NONE` if the document has no forms.
+        """
+        return pdfium_c.FPDF_GetFormType(self)
+    
+    
     def get_pagemode(self):
         """
         Returns:
@@ -265,12 +275,9 @@ class PdfDocument (AutoCloseable):
         Returns:
             dict: PDF metadata.
         """
-        metadata = {}
-        for key in self.METADATA_KEYS:
-            value = self.get_metadata_value(key)
-            if skip_empty and not value:
-                continue
-            metadata[key] = value
+        metadata = {k: self.get_metadata_value(k) for k in self.METADATA_KEYS}
+        if skip_empty:
+            metadata = {k: v for k, v in metadata.items() if v}
         return metadata
     
     
@@ -332,7 +339,7 @@ class PdfDocument (AutoCloseable):
             PdfPage: The page at *index* (zero-based).
         Note:
             This calls ``FORM_OnAfterLoadPage()`` if the document has an active form env.
-            The form env must no be closed before the page is closed!
+            The form env must not be closed before the page is closed!
         """
         
         raw_page = pdfium_c.FPDF_LoadPage(self, index)
@@ -372,6 +379,7 @@ class PdfDocument (AutoCloseable):
         """
         Remove the page at *index* (zero-based).
         """
+        # FIXME what if the caller still has a handle to the page?
         pdfium_c.FPDFPage_Delete(self, index)
     
     
@@ -445,7 +453,7 @@ class PdfDocument (AutoCloseable):
         
         raw_xobject = pdfium_c.FPDF_NewXObjectFromPage(dest_pdf, self, index)
         if raw_xobject is None:
-            raise PdfiumError(f"Failed to capture page {index} as FPDF_XOBJECT.")
+            raise PdfiumError(f"Failed to capture page at index {index} as FPDF_XOBJECT.")
         
         return PdfXObject(
             raw = raw_xobject,
@@ -534,12 +542,17 @@ class PdfDocument (AutoCloseable):
     
     
     @classmethod
-    def _process_page(cls, index, input_data, password, renderer, converter, pass_info, **kwargs):
+    def _process_page(cls, index, input_data, password, renderer, converter, pass_info, need_formenv, mk_formconfig, **kwargs):
         
         pdf = cls(
             input_data,
             password = password,
         )
+        if need_formenv:
+            if mk_formconfig:
+                pdf.init_forms(config=mk_formconfig())
+            else:
+                pdf.init_forms()
         page = pdf[index]
         
         bitmap = renderer(page, **kwargs)
@@ -562,6 +575,7 @@ class PdfDocument (AutoCloseable):
             page_indices = None,
             n_processes = os.cpu_count(),
             pass_info = False,
+            mk_formconfig = None,
             **kwargs
         ):
         """
@@ -581,6 +595,8 @@ class PdfDocument (AutoCloseable):
                 The number of parallel process to use.
             renderer (typing.Callable):
                 The page rendering function to use. This may be used to plug in custom renderers other than :meth:`.PdfPage.render`.
+            mk_formconfig (typing.Callable[FPDF_FORMFILLINFO] | None):
+                Optional callback returning a custom form config to use when initializing a form env in worker jobs.
             kwargs (dict):
                 Keyword arguments to the renderer.
         
@@ -607,6 +623,8 @@ class PdfDocument (AutoCloseable):
             renderer = renderer,
             converter = converter,
             pass_info = pass_info,
+            need_formenv = bool(self.formenv),
+            mk_formconfig = mk_formconfig,
             **kwargs
         )
         
