@@ -83,88 +83,85 @@ class PdfPage (AutoCloseable):
         pdfium_c.FPDFPage_SetRotation(self, consts.RotationToConst[rotation])
     
     
-    def _get_box(self, box_func, fallback_func):
+    def _get_box(self, box_func, fallback_func, fallback_ok):
         left, bottom, right, top = c_float(), c_float(), c_float(), c_float()
         success = box_func(self, left, bottom, right, top)
         if not success:
-            return fallback_func()
+            return (fallback_func() if fallback_ok else None)
         return (left.value, bottom.value, right.value, top.value)
     
-    def _set_box(self, box_func, l, b, r, t):
-        if not all(isinstance(val, (int, float)) for val in (l, b, r, t)):
-            raise ValueError("Box values must be int or float.")
-        box_func(self, l, b, r, t)
+    # NOTE in case further arguments are needed (besides fallback_ok), then use *args, **kwargs in callers
     
-    def get_mediabox(self):
+    def get_mediabox(self, fallback_ok=True):
         """
         Returns:
-            (float, float, float, float):
+            (float, float, float, float) | None:
             The page MediaBox in PDF canvas units, consisting of four coordinates (usually x0, y0, x1, y1).
-            Falls back to ANSI A (0, 0, 612, 792) in case MediaBox is not defined.
+            If MediaBox is not defined, returns ANSI A (0, 0, 612, 792) if ``fallback_ok=True``, None otherwise.
         Note:
             Due to quirks in PDFium's public API, all ``get_*box()`` functions except :meth:`.get_bbox`
             do not inherit from parent nodes in the page tree (as of PDFium 5418).
         """
         # https://crbug.com/pdfium/1786
-        return self._get_box(pdfium_c.FPDFPage_GetMediaBox, lambda: (0, 0, 612, 792))
+        return self._get_box(pdfium_c.FPDFPage_GetMediaBox, lambda: (0, 0, 612, 792), fallback_ok)
     
     def set_mediabox(self, l, b, r, t):
         """
         Set the page's MediaBox by passing four :class:`float` coordinates (usually x0, y0, x1, y1).
         """
-        self._set_box(pdfium_c.FPDFPage_SetMediaBox, l, b, r, t)
+        pdfium_c.FPDFPage_SetMediaBox(self, l, b, r, t)
     
-    def get_cropbox(self):
+    def get_cropbox(self, fallback_ok=True):
         """
         Returns:
             The page's CropBox (If not defined, falls back to MediaBox).
         """
-        return self._get_box(pdfium_c.FPDFPage_GetCropBox, self.get_mediabox)
+        return self._get_box(pdfium_c.FPDFPage_GetCropBox, self.get_mediabox, fallback_ok)
     
     def set_cropbox(self, l, b, r, t):
         """
         Set the page's CropBox.
         """
-        self._set_box(pdfium_c.FPDFPage_SetCropBox, l, b, r, t)
+        pdfium_c.FPDFPage_SetCropBox(self, l, b, r, t)
     
-    def get_bleedbox(self):
+    def get_bleedbox(self, fallback_ok=True):
         """
         Returns:
             The page's BleedBox (If not defined, falls back to CropBox).
         """
-        return self._get_box(pdfium_c.FPDFPage_GetBleedBox, self.get_cropbox)
+        return self._get_box(pdfium_c.FPDFPage_GetBleedBox, self.get_cropbox, fallback_ok)
     
     def set_bleedbox(self, l, b, r, t):
         """
         Set the page's BleedBox.
         """
-        self._set_box(pdfium_c.FPDFPage_SetBleedBox, l, b, r, t)
+        pdfium_c.FPDFPage_SetBleedBox(self, l, b, r, t)
     
-    def get_trimbox(self):
+    def get_trimbox(self, fallback_ok=True):
         """
         Returns:
             The page's TrimBox (If not defined, falls back to CropBox).
         """
-        return self._get_box(pdfium_c.FPDFPage_GetTrimBox, self.get_cropbox)
+        return self._get_box(pdfium_c.FPDFPage_GetTrimBox, self.get_cropbox, fallback_ok)
     
     def set_trimbox(self, l, b, r, t):
         """
         Set the page's TrimBox.
         """
-        self._set_box(pdfium_c.FPDFPage_SetTrimBox, l, b, r, t)
+        pdfium_c.FPDFPage_SetTrimBox(self, l, b, r, t)
     
-    def get_artbox(self):
+    def get_artbox(self, fallback_ok=True):
         """
         Returns:
             The page's ArtBox (If not defined, falls back to CropBox).
         """
-        return self._get_box(pdfium_c.FPDFPage_GetArtBox, self.get_cropbox)
+        return self._get_box(pdfium_c.FPDFPage_GetArtBox, self.get_cropbox, fallback_ok)
     
     def set_artbox(self, l, b, r, t):
         """
         Set the page's ArtBox.
         """
-        self._set_box(pdfium_c.FPDFPage_SetArtBox, l, b, r, t)
+        pdfium_c.FPDFPage_SetArtBox(self, l, b, r, t)
     
     
     def get_bbox(self):
@@ -348,7 +345,7 @@ class PdfPage (AutoCloseable):
                 Amount in PDF canvas units to cut off from page borders (left, bottom, right, top). Crop is applied after rotation.
                 
             may_draw_forms (bool):
-                If True, render form fields (provided the document has forms and was opened with ``may_init_forms=True``).
+                If True, render form fields (provided the document has forms and :meth:`~PdfDocument.init_forms` was called).
             
             bitmap_maker (typing.Callable):
                 Callback function used to create the :class:`.PdfBitmap`.
