@@ -115,8 +115,6 @@ class PdfObject (AutoCloseable):
         Parameters:
             matrix (PdfMatrix): Set this matrix as the pageobject's transform matrix.
         """
-        if not isinstance(matrix, PdfMatrix):
-            raise ValueError("*matrix* must be a PdfMatrix object.")
         success = pdfium_c.FPDFPageObj_SetMatrix(self, matrix)
         if not success:
             raise PdfiumError("Failed to set matrix of pageobject.")
@@ -127,8 +125,6 @@ class PdfObject (AutoCloseable):
         Parameters:
             matrix (PdfMatrix): Multiply the page object's current transform matrix by this matrix.
         """
-        if not isinstance(matrix, PdfMatrix):
-            raise ValueError("*matrix* must be a PdfMatrix object.")
         pdfium_c.FPDFPageObj_Transform(self, *matrix.get())
 
 
@@ -176,9 +172,8 @@ class PdfImage (PdfObject):
         
         # https://crbug.com/pdfium/1928
         
-        raw_page = (self.page if self.page else None)
         metadata = pdfium_c.FPDF_IMAGEOBJ_METADATA()
-        success = pdfium_c.FPDFImageObj_GetImageMetadata(self, raw_page, metadata)
+        success = pdfium_c.FPDFImageObj_GetImageMetadata(self, self.page, metadata)
         if not success:
             raise PdfiumError("Failed to get image metadata.")
         
@@ -265,8 +260,7 @@ class PdfImage (PdfObject):
         if render:
             if self.pdf is None:
                 raise RuntimeError("Cannot get rendered bitmap of loose page object.")
-            raw_page = (self.page if self.page else None)
-            raw_bitmap = pdfium_c.FPDFImageObj_GetRenderedBitmap(self.pdf, raw_page, self)
+            raw_bitmap = pdfium_c.FPDFImageObj_GetRenderedBitmap(self.pdf, self.page, self)
         else:
             raw_bitmap = pdfium_c.FPDFImageObj_GetBitmap(self)
         
